@@ -231,17 +231,18 @@ class NodeTreeData():
 def disconnect():
     #ifCMD = ["ifconfig", "-a"]
     #ifgrepCMD = ["grep", "-oE", "wg[0-9]+"]
-    partCMD = ['pkexec', 'env', 'PATH=%s' % ConfParams.PATH, sentinelcli, '--home', ConfParams.BASEDIR, "disconnect"]
-    
+    #partCMD = ['pkexec', 'env', 'PATH=%s' % ConfParams.PATH, sentinelcli, '--home', ConfParams.BASEDIR, "disconnect"]
+    #partCMD  = ['pkexec', 'env', 'PATH=%s' % ConfParams.PATH, 'wg-quick', 'down']
     #ifoutput = Popen(ifCMD,stdin=PIPE, stdout=PIPE, stderr=STDOUT)
     #grepoutput = Popen(ifgrepCMD, stdin=ifoutput.stdout, stdout=PIPE, stderr=STDOUT)
     #wgif = grepoutput.communicate()[0]
     #wgif_file = str(wgif.decode('utf-8')).replace("\n", '') + ".conf"
 
     #CONFFILE = path.join(BASEDIR, wgif_file)
-    #wg_downCMD = ['wg-quick', 'down', CONFFILE]
+    CONFFILE = path.join(ConfParams.BASEDIR, 'wg99.conf')
+    wg_downCMD = ['pkexec', 'env', 'PATH=%s' % ConfParams.PATH, 'wg-quick', 'down', CONFFILE]
         
-    proc1 = Popen(partCMD)
+    proc1 = Popen(wg_downCMD)
     proc1.wait(timeout=30)
     
     #proc = Popen(wg_downCMD, stdout=PIPE, stderr=PIPE)
